@@ -20,7 +20,7 @@ import re
 import shutil
 import tempfile
 
-version = "0.5.1"
+version = "0.5.2"
 
 re_options = re.IGNORECASE | re.MULTILINE | re.DOTALL
 skip_pattern = re.compile('# hghooks: (.*)', re_options)
@@ -50,10 +50,10 @@ class CheckerManager(object):
         current_rev = self.repo[self.node].rev()
         total_revs = len(self.repo.changelog)
         while current_rev < total_revs:
-            current_rev += 1
             rev_warnings = 0
-            directory = tempfile.mkdtemp(suffix='-r%d' % (current_rev - 1),
+            directory = tempfile.mkdtemp(suffix='-r%d' % current_rev,
                                          prefix='hghooks')
+            current_rev += 1
 
             self.ui.debug("Checking revision %d\n" % current_rev)
             ctx = self.repo[current_rev - 1]
@@ -92,4 +92,4 @@ class CheckerManager(object):
         if warnings:
             return True   # failure
         else:
-            return False  # sucess
+            return False  # success
